// Using code from the I2C guide 

// Assume pins already configured for I2C:

// For Bus 1:
// (bbg)$ config-pin P9_17 i2c
// (bbg)$ config-pin P9_18 i2c


// For Bus 2:
// (bbg)$ config-pin P9_19 i2c
// (bbg)$ config-pin P9_20 i2c

#define I2CDRV_LINUX_BUS0 "/dev/i2c-0"
#define I2CDRV_LINUX_BUS1 "/dev/i2c-1"
#define I2CDRV_LINUX_BUS2 "/dev/i2c-2"

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <linux/i2c.h>
#include <linux/i2c-dev.h>
#include <time.h>

#define I2C_DEVICE_ADDRESS 0x70

#define REG0 0x00
#define REG1 0x01
#define REG2 0x02
#define REG3 0x03
#define REG4 0x04
#define REG5 0x05
#define REG6 0x06
#define REG7 0x07
#define REG8 0x08
#define REG9 0x09

#define REG21 0x21

#define ALL_BITS_ON 0xFF
#define ALL_BITS_OFF 0x00

#define REG_TURN_ON 0x81
#define REG_TURN_OFF 0x80



static int initI2cBus(char* bus, int address)
{
	int i2cFileDesc = open(bus, O_RDWR);
	int result = ioctl(i2cFileDesc, I2C_SLAVE, address);

	if (result < 0) {
		perror("I2C: Unable to set I2C device to slave address.");
		exit(1);
	}

	return i2cFileDesc;
}

static void writeI2cReg(int i2cFileDesc, unsigned char regAddr, unsigned char value)
{
	unsigned char buff[2];
	buff[0] = regAddr;
	buff[1] = value;
	int res = write(i2cFileDesc, buff, 2);

	if (res != 2) {
		perror("I2C: Unable to write i2c register.");
		exit(1);
	}
}


// Insert the above functions here...
int main()
{
	// Change I2CDRV_LINUX_BUS2 to I2CDRV_LINUX_BUS1 if using Bus 1
	int i2cFileDesc = initI2cBus(I2CDRV_LINUX_BUS2, I2C_DEVICE_ADDRESS);
	
	// Initialize all the symbols on the display 
	writeI2cReg(i2cFileDesc, REG0, 0xFF);
	writeI2cReg(i2cFileDesc, REG1, 0xFF);
	writeI2cReg(i2cFileDesc, REG2, 0xFF);
	writeI2cReg(i2cFileDesc, REG3, 0xFF);
	writeI2cReg(i2cFileDesc, REG4, 0xFF);
	writeI2cReg(i2cFileDesc, REG5, 0xFF);
	writeI2cReg(i2cFileDesc, REG6, 0xFF);
	writeI2cReg(i2cFileDesc, REG7, 0xFF);
	writeI2cReg(i2cFileDesc, REG8, 0xFF);
	writeI2cReg(i2cFileDesc, REG9, 0xFF);
	
	writeI2cReg(i2cFileDesc, REG21, 0xFF);
	
	// Fully turn on the display
	writeI2cReg(i2cFileDesc, REG_TURN_ON, 0x00);
	
	// Clear registers
	writeI2cReg(i2cFileDesc, REG0, 0x00);
	writeI2cReg(i2cFileDesc, REG1, 0x00);
	writeI2cReg(i2cFileDesc, REG2, 0x00);
	writeI2cReg(i2cFileDesc, REG3, 0x00);
	writeI2cReg(i2cFileDesc, REG4, 0x00);
	writeI2cReg(i2cFileDesc, REG5, 0x00);
	writeI2cReg(i2cFileDesc, REG6, 0x00);
	writeI2cReg(i2cFileDesc, REG7, 0x00);
	
	// Write "User" onto the alphanumeric display
	writeI2cReg(i2cFileDesc, REG0, 0x3e);
	writeI2cReg(i2cFileDesc, REG2, 0xed);
	writeI2cReg(i2cFileDesc, REG3, 0x00);
	writeI2cReg(i2cFileDesc, REG4, 0xf9);
	writeI2cReg(i2cFileDesc, REG6, 0xf3);
	writeI2cReg(i2cFileDesc, REG7, 0x20);

	// Cleanup I2C access;
	close(i2cFileDesc);
	return 0;
}
